#############################
#
# n-log configuration file
#
#############################

#--------------------------#
#---- required modules ----#
#--------------------------#


BEGIN {
    $Success = 1;
    print ("Content-type: text/html\n\n");
    @required_modules = ("CGI", "CGI::Carp", "Socket");
    %failed_modules = ();
    $HAVE_LWP = 1;
    
    for $mod (@required_modules) {    
        if (eval "require $mod") {    
            $mod->import();
        }   else {
            $failed_modules{$mod} = $@;
            $Success = 0;
        }
    }   

    if (eval "require LWP::Simple") {
        LWP::Simple->import();
    } else {
        $HAVE_LWP = 0;
    }
}

# print an error if any of our required modules werent found
MissingRequiredModules() unless $Success;

# create an intial CGI query object
$query = CGI->new();

#--------------------------#
#---- system variables ----#
#--------------------------#

# you MUST change these values to match your system

# our base directory to read the databases from
# we dont allow access to any files outside of this directory

$dbdir = "/tmp/db";

# cgi-bin directory containing nlog-search + extension scripts (rpc/smb/finger/etc)
# this path is the WEB path not the local path

$cgidir = "/cgi-bin/nlog";

# admin e-mail address (keep the ' ' quotes on it)
# as of 1.5.3 this isnt actually used yet.

$admin = 'nlog@ings.com';

# enable warning mails about attempted hacks...
# not actually implemented yet.
# 0 = off, 1 = on

$hackwarn = 0;


#-------------------------#
#--- program locations ---#
#-------------------------#

#
# this is where our scripts get the full pathnames to the programs 
# they call, if you dont have a program listed here, disable its 
# extension in the 'nlog entensions and hyperlinks settings'
# section of this config file.
#


# the 'date' command
$date = "/bin/date";

# ( nlog-finger.pl )
$finger = "/usr/sbin/safe_finger";

# ( nlog-smb.pl )
$nmblookup = "/usr/bin/nmblookup";
$smbclient = "/usr/bin/smbclient";

# samba variables used in all operations
$fWORKGROUP = "WORKGROUP";
$fUSER      = "nobody";
$fNAME      = "NLOG";

#  ( nlog-rpc.pl )
$rpcinfo = "/usr/bin/rpcinfo";
$showmount = "/usr/sbin/showmount";

#-------------------------------------------------------#
#---- access remote databases via a URL for db name ----#
#-------------------------------------------------------#

# we require the LWP module to retrieve remote databases

# Using LYNX is *NOT* Safe
# its possible for anyone accessing
# your CGI to run commands on your server
# as your CGI user

# do we allow users to load remote databases
# from http URL's? [ 0 = no / 1 = yes ]
#
# NOTE: You *must* have the LWP::Simple module available
#

$REMOTE_DB = 0;


#-------------------------------------------------#
#---- nlog entensions and hyperlinks settings ----#
#-------------------------------------------------#

# this lets you resolve host names by clicking the ip address
$nshandler = "$cgidir/nlog-dns.pl";

# what to show as a hyperlink.. etc..
# format for 'normal' links are service+protocol ( www+http )
# each entry separated by a space, each serv/proto separated by a plus

@qlinks = split(/\s+/,"www+http telnet+telnet ftp+ftp rlogin+telnet");

# now come the cgi links...
# format is service+cgi-path+Display ( sunrpc+$cgidir/nlog-rpc.pl+SunRPC )
# the IP of the current host is sent as the query string
# the output looks like Display(ip_address) with a link to the cgi

# here we place each cgi-handler into a temp var for readability.

$cgiSunRPC = "sunrpc+$cgidir/nlog-rpc.pl+SunRPC";
$cgiSMB    = "netbios-ssn+$cgidir/nlog-smb.pl+NetBIOS";
$cgiFinger = "finger+$cgidir/nlog-finger.pl+Finger";

@qcgilinks = split(/\s+/,"$cgiSunRPC $cgiSMB $cgiFinger");



#-------------------------------------#
#---- do not edit below this line ----#
#-------------------------------------#

# our version number
$version = "1.5.3";

# umask for all file operations
# paranoia ;)

$umask ="077";


sub printfooters {

print '<p align="center"><small><font face="Verdana">';
print "<br>n-log v$version<br>";
print 'questions, comments, or suggestions: email the author at';
print ' <a href="mailto:nlog@ings.com">nlog@ings.com</a>';
print '</font></small></p></body></html>';

}

sub checkip {

    my ($ip) = @_;
    my $binip = gethostbyname($ip);

    if ($binip) {
        return inet_ntoa($binip);
    } else {
        $ourdate = `$date`;
        $ourdate = chomp($ourdate);
        # evil users...
        # give them a scare message...

        print "<pre>";
        print "The address passed to this program is not a valid IP address.\n<br>";
        print "This attempt has been logged and the administrator has been notified.\n";
        print "<br><br>Date:     $ourdate\n<br>";
        print "Host:     $ENV{'REMOTE_ADDR'}\n<br>";
        print "Query:    $ip\n<br>";
        print "</pre>";
        print "</p></small></font></body></html>";

        if ($hackwarn eq 1) {
            # if hackwarn is defined, email admin
            # !! not implemented !!        
        }    
        exit(0);
    }
}

sub resolveip {
    my $results;
    my ($ip) = @_;
    my $binip = gethostbyname($ip);
    my ($hostname) = gethostbyaddr($binip,AF_INET);
    if ($hostname && $binip) {
        my $newip = gethostbyname($hostname);
        my ($newhost) = gethostbyaddr($newip,AF_INET);
        
        if ($newip ne $binip || $hostname ne $newhost) {
            $results .= "The re-resolved ip addresses do not match:\n";
            $results .= inet_ntoa($binip) . "($hostname) is not " . inet_ntoa($newip) . "($newhost)\n";
        } else {
            $results .= "The address $ip resolved to $hostname (" . inet_ntoa($binip) . ")\n";
        }
    } else {
        if ($binip) {
            $results .= "That address (" . inet_ntoa($binip) . ") has no hostname associated with it.\n";
        } else {
            $results .="That address does not exist.\n";
        }
    }
    return $results;
}

sub dienice {
    ($msg) = @_;
    print "<h2>Error</h2>\n";
    print $msg;
    exit 0;
}

sub MissingRequiredModules {
    print ("<html><head><title>nlog error:  Failed to load required modules</title></head>");
    print ("<body bgcolor=\"ffffff\" text=\"000000\"><font face=\"Verdana\">");
    print ("Your system is unable to run nlog because you are missing the following modules:<hr><br><p><pre>");
    for $mod (keys(%failed_modules)) {
        print ("$mod:\t". $failed_modules{$mod} . "\n");
    }
    print ("</pre></p></font></body></html>");
    exit(0);
}

sub disabled {

    $back = $ENV{'HTTP_REFFERER'};

    print "Content-type: text/html\n\n";
    &printstdheader("Disabled");
    print "The function you tried to access has been disabled.\n<br>";
    print "Click <a href =\"$back\">Here</a> to go back.\n";
    &printfooters;
}

sub printstdheader {

($title) = @_;

print <<THEHEADER
<html>

<head>
<style>
<!--
A:link        { text-decoration: none; }
A:active      { text-decoration: none; }
A:visited     { text-decoration: none; }
A:hover       {COLOR = #FFFF00 }
//-->
</style>
<title>$title</title>
</head>
<body BGCOLOR="#000000" TEXT="#FFFFFF" LINK="#CCCCFF" ALINK="#FF0000" VLINK="#FF000C">
<!--// Generated by nlog v$version :   http://nlog.ings.com //-->

THEHEADER
;

}
